// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * AMD module for search page.
 *
 * @module     enrol_ubxsshib/search
 * @copyright  2022 Universite de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

import * as url from 'core/url';

/**
 *
 * @return {boolean}
 */
const open_search_window = () => {
    let cc1 = document.getElementById('id_customchar1');
    let value = cc1.options[cc1.selectedIndex].value;
    let ci = document.getElementsByName("courseid")[0];
    let params = {
        'course': ci.value,
        'codetype': value,
    };
    var u = url.relativeUrl('/enrol/ubxsshib/search.php', params);

    return window.open(u, 'ubxsshibsearch',
        'menubar=1,location=1,directories=1,toolbar=1,scrollbars,resizable,width=800,height=600');
};

/**
 *
 * @param {Object} lnk
 * @return {undefined}
 */
const set_opener_fields = (lnk) => {
    let codetype = document.getElementById('id_codetype');
    let code = lnk.attributes['data-apo-code'].value;
    let desc = lnk.attributes['data-apo-desc'].value;

    var namefield = window.opener.document.querySelector("[data-apo-field='name']");
    if (namefield) {
        namefield.value=desc;
    }

    var typefield = window.opener.document.querySelector("[data-apo-field='codetype']");
    if (typefield) {
        typefield.value = codetype.options[codetype.selectedIndex].value;
    }

    var codefield = window.opener.document.querySelector("[data-apo-field='codevalue']");
    if (codefield) {
        codefield.value = code;
    }
    window.close();
};

export const initEditForm = () => {
    var sb = document.getElementById('id_searchbutton');
    if (sb) {
        sb.addEventListener('click', () => {
            open_search_window();
        });
    }
};

export const initSearchForm = () => {
    var grouplinks = document.getElementsByClassName('group-link');
    if (grouplinks) {
        [...grouplinks].forEach((lnk) => {
            lnk.addEventListener('click', e => {
                e.preventDefault();
                set_opener_fields(lnk);
            });
        });
    }
};

export const closesWindow = () => {
    window.close();
};
