<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Class to intercat with LDAP server.
 *
 * @package    enrol_ubxsshib
 * @copyright  2020 - MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace enrol_ubxsshib;

defined('MOODLE_INTERNAL') || die();

/**
 * Interface for group providers.
 */
interface IGroupProvider {
    /**
     * Returns groups of type $codetype containing $searchtext in description.
     * @param string $searchtext
     * @param string $grouptype
     * @return enrol_ubxsshib_groupinfo[]
     */
    public function search_groups($searchtext, $grouptype);

    /**
     * Returns group of type $codetype identified by its $groupecode.
     * If $withmembers is true, members are also extracted.
     * @param string $codetype
     * @param string $groupcode
     * @param boolean $withmembers
     * @return enrol_ubxsshib_groupinfo
     */
    public function get_group($grouptype, $groupcode, $withmembers = false);

    /**
     * Returns users (user_info) matching $criteria.
     * @param string[] $criteria
     * @return user_info[]
     */
    public function search_users($criteria);

    /**
     * Returns userinfo for the provided $username.
     * @param string $username
     * @return user_info
     */
    public function get_userinfo($username);
}
