<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * The enrol_ubxsshib force enrol completed event.
 *
 * @package    enrol_ubxsshib
 * @copyright  2020 MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace enrol_ubxsshib\event;

defined('MOODLE_INTERNAL') || die();

/**
 * The enrol_ubxsshib force enrol completed event class.
 *
 * @property-read array $other {
 *      Extra information about the event.
 *
 *      - int methodid : enrol method id.
 *      - string methodname : enrol method name.
 *      - int userid : id of the user who launched the task.
 * }
 *
 * @package    enrol_ubxsshib
 * @copyright  2020 MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class forceenrol_completed extends \core\event\base {

    /**
     * Init method.
     *
     * @return void
     */
    protected function init() {
        $this->data['crud'] = 'u';
        $this->data['edulevel'] = self::LEVEL_TEACHING;
    }

    /**
     * Returns description of what happened.
     *
     * @return string
     */
    public function get_description() {
        $methodname = $this->other['methodname'];

        return "Forced synchronization of Apogee enrol method $methodname of course $this->courseid, launched by user #$this->userid, completed.";
    }

    /**
     * Return localised event name.
     *
     * @return string
     */
    public static function get_name() {
        return get_string('forceenrolcompleted_eventname', 'enrol_ubxsshib');
    }

    /**
     * Get URL related to the action
     *
     * @return \moodle_url
     */
    public function get_url() {
        return new \moodle_url('/enrol/instances.php', [
            'id' => $this->courseid,
        ]);
    }

    /**
     * Return the legacy event log data.
     *
     * @return array|null
     */
    protected function get_legacy_logdata() {
        return [];
    }

    /**
     * Custom validation.
     *
     * @throws \coding_exception
     * @return void
     */
    protected function validate_data() {
        parent::validate_data();
    }

    /**
     * {@inheritdoc}
     *
     * @return array an array of other values and their corresponding mapping
     */
    public static function get_other_mapping() {
        return false;
    }
}
