<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace enrol_ubxsshib\form;

defined('MOODLE_INTERNAL') || die();

use moodleform;
use enrol_ubxsshib\ubxsshib_enrol_method;

require_once($CFG->libdir . '/formslib.php');
require_once($CFG->dirroot . '/enrol/ubxsshib/locallib.php');

/**
 * Search form for UBxS shibboleth enrol plugin.
 *
 * @package    enrol_ubxsshib
 * @copyright  2014 - MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class search_form extends moodleform {

    /**
     * {@inheritdoc}
     *
     * @return void
     * @throws \coding_exception
     * @throws \dml_exception
     */
    protected function definition() {

        $mform = $this->_form;

        list($context, $codetype) = $this->_customdata;

        $mform->addElement('header', 'searchheader', get_string('searchheader', 'enrol_ubxsshib'));

        $options = [
            ubxsshib_enrol_method::CODE_ETAPE => get_string('etape_choice', 'enrol_ubxsshib'),
            ubxsshib_enrol_method::CODE_ELEMENTPEDAGO => get_string('elp_choice', 'enrol_ubxsshib'),
            ubxsshib_enrol_method::CODE_EPREUVE => get_string('exam_choice', 'enrol_ubxsshib',
        ];
        $mform->addElement('select', 'codetype', 'Type', $options);
        $mform->setDefault('codetype', $codetype);

        $mform->addElement('text', 'searchtext', get_string('searchtext', 'enrol_ubxsshib'));
        $mform->setType('searchtext', PARAM_TEXT);
        $mform->addRule('searchtext', null, 'required', null, 'client');
        $mform->addHelpButton('searchtext', 'searchtext', 'enrol_ubxsshib');

        if ($context && isset($context->id)) {
            $mform->addElement('hidden', 'course', $context->id);
            $mform->setType('course', PARAM_INT);
        }

        $buttonarray = [];
        $buttonarray[] = &$mform->createElement('submit', 'searchsubmit', get_string('searchsubmit', 'enrol_ubxsshib'));
        $buttonarray[] = &$mform->createElement('cancel');
        $mform->addGroup($buttonarray, 'buttonar', '', [' '], false);
    }
}
