<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Group observers.
 *
 * @package    enrol_ubxsshib
 * @copyright  2018 MAPI - Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace enrol_ubxsshib;

use core\exception\moodle_exception;

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot . '/enrol/ubxsshib/locallib.php');

/**
 * Observers class.
 *
 * @package    enrol_ubxsshib
 * @copyright  2018 MAPI - Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class observers {

    /**
     * A group was deleted.
     *
     * @param \core\event\base $event The event.
     * @return void
     */
    public static function group_deleted($event) {
        enrol_ubxsshib_remove_group_from_method($event->objectid);
    }

    /**
     * Triggered when forced enrolment is started.
     *
     * @param \enrol_ubxsshib\event\forceenrol_started $event The event.
     * @return void
     * @throws moodle_exception
     */
    public static function forceenrol_started($event) {
        $methodname = $event->other['methodname'];
        $userid = $event->other['userid'];
        $enrolinstancesurl = new \moodle_url('/enrol/instances.php', ["id" => $event->courseid]);

        $message = new \core\message\message();
        $message->component = 'enrol_ubxsshib';
        $message->name = 'forceenrolstarted_notification';
        $message->userfrom = \core_user::get_noreply_user();
        $message->userto = $userid;
        $message->subject = get_string('forceenrol_started_notif_subject', 'enrol_ubxsshib');
        $a = (object)['methodname' => $methodname];
        $message->fullmessage = get_string('forceenrol_started_notif_fullmessage', 'enrol_ubxsshib', $a);
        $a = (object)['url' => $enrolinstancesurl, 'methodname' => $methodname];
        $message->fullmessageformat = FORMAT_HTML;
        $message->fullmessagehtml = get_string('forceenrol_started_notif_fullmessagehtml', 'enrol_ubxsshib', $a);
        $message->smallmessage = get_string('forceenrol_started_notif_smallmessage', 'enrol_ubxsshib');
        $message->notification = 1;
        $message->contexturl = $enrolinstancesurl;
        $message->contexturlname = get_string('enrolmentinstances', 'enrol');
        $message->courseid = $event->courseid;
        message_send($message);
    }

    /**
     * Triggered when forced enrolment has ended.
     *
     * @param \enrol_ubxsshib\event\forceenrol_completed $event The event.
     * @return void
     * @throws moodle_exception
     */
    public static function forceenrol_completed($event) {
        $methodname = $event->other['methodname'];
        $userid = $event->other['userid'];
        $enrolinstancesurl = new \moodle_url('/enrol/instances.php', ["id" => $event->courseid]);

        $message = new \core\message\message();
        $message->component = 'enrol_ubxsshib';
        $message->name = 'forceenrolcompleted_notification';
        $message->userfrom = \core_user::get_noreply_user();
        $message->userto = $userid;
        $message->subject = get_string('forceenrol_completed_notif_subject', 'enrol_ubxsshib');
        $a = (object)['methodname' => $methodname];
        $message->fullmessage = get_string('forceenrol_completed_notif_fullmessage', 'enrol_ubxsshib', $a);
        $a = (object)['url' => $enrolinstancesurl, 'methodname' => $methodname];
        $message->fullmessageformat = FORMAT_HTML;
        $message->fullmessagehtml = get_string('forceenrol_completed_notif_fullmessagehtml', 'enrol_ubxsshib', $a);
        $message->smallmessage = get_string('forceenrol_completed_notif_smallmessage', 'enrol_ubxsshib');
        $message->notification = 1;
        $message->contexturl = new \moodle_url('/enrol/instances.php', ["id" => $event->courseid]);
        $message->contexturlname = get_string('enrolmentinstances', 'enrol');
        $message->courseid = $event->courseid;
        message_send($message);
    }
}
