<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Ubxsshib enrolment method renderer.
 *
 * @package    enrol_ubxsshib
 * @copyright  2021 - MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
namespace enrol_ubxsshib\output;

defined('MOODLE_INTERNAL') || die;

use plugin_renderer_base;
use html_writer;
use html_table;
use html_table_row;
use html_table_cell;

/**
 * Remote courses migration tool renderer.
 *
 * @package    enrol_ubxsshib
 * @copyright  2022 - MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class renderer extends plugin_renderer_base {

    /**
     * Return rendered list of Apogee search results.
     *
     * @param array $results
     * @return string HTML string
     * @throws \coding_exception
     */
    public function search_results($results) {
        $rendered = '';

        if (count($results) > 0) {
            $table = new html_table();
            $table->head = ['Code', 'Description'];
            $table->attributes["style"] = 'width:100%;';
            $table->size = ['20%', '80%'];
            $table->data = [];
            foreach ($results as $result) {
                $table->data[] = $this->render_result($result);
            }
            echo html_writer::table($table);
        } else {
            echo get_string('searchnoresult', 'enrol_ubxsshib');
        }

        return $rendered;
    }

    /**
     * Render a single result.
     *
     * @param array $result
     * @return html_table_row
     */
    private function render_result($result) {
        $row = new html_table_row();
        $codecell = new html_table_cell();
        $desccell = new html_table_cell();

        $desctext = $result->description;

        $codecell->text = \html_writer::start_tag('strong') .
            html_writer::link('#', $result->code, ['class' => 'group-link', 'data-apo-code' => $result->code, 'data-apo-desc' => $desctext]) .
            html_writer::end_tag('strong');
        $desccell->text = $desctext;

        $row->cells = [$codecell, $desccell];

        return $row;
    }
}
