<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Sync enrolments task
 * @package    enrol_ubxsshib
 * @copyright  2020 MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace enrol_ubxsshib\task;

defined('MOODLE_INTERNAL') || die();

class sync_enrolments extends \core\task\scheduled_task {

    /**
     * Name for this task.
     *
     * @return string
     */
    public function get_name() {
        return get_string('syncenrolmentstask', 'enrol_ubxsshib');
    }

    /**
     * Run task for synchronizing users.
     */
    public function execute() {
        if (!enrol_is_enabled('ubxsshib')) {
            mtrace(get_string('pluginnotenabled', 'enrol_ubxsshib'));
            exit(0); // Note, exit with success code, this is not an error - it's just disabled.
        }

        $trace = new \text_progress_trace();

        /** @var enrol_ubxsshib_plugin $plugin */
        $plugin = enrol_get_plugin('ubxsshib');

        if ($plugin->get_config('inhibit_all', false)) {
            $trace->output('All methods are disabled in plugin settings.');
        } else {
            // Delete userinfo cache entries to make sure we synchronize against current data.
            $cache = \cache::make('enrol_ubxsshib', 'userinfo');
            $cache->purge();

            // Sync enrolments.
            $plugin->sync_enrolments($trace);

            $trace->output('All methods synchronized.');
        }
        $trace->finished();
    }
}
