<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Class to manage ubxsshib enrolment method based on 'UE'.
 *
 * @package    enrol_ubxsshib
 * @copyright  2022 - MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace enrol_ubxsshib;

/**
 * Class to manage ubxsshib enrolment method based on 'UE'.
 *
 * @package    enrol_ubxsshib
 * @copyright  2022 - MAPI Université de Bordeaux
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class ubxsshib_enrol_elmt_method extends ubxsshib_enrol_method {

    /**
     * Enrol the provided user through this method.
     *
     * @param stdClass $user
     */
    public function enrol_user($user) {
        parent::enrol_user($user);

        // TODO: verify groupid hasn't changed ?
        // TODO: verify roleid hasn't changed ?
    }

    public function unenrol_user($user) {
        parent::unenrol_user($user);
    }

    protected function get_ldap_groups($user) {
        $groups = [];

        return $groups;
    }

    protected function enrol_user_in_group($user, $groupcode) {
        $courseid = $this->instance->courseid;
        $idnumber = $this->get_coursegroup_identifier($groupcode);
        $groupid = groups_get_group_by_idnumber($courseid, $idnumber);
        if (!$groupid) {
            $data = new \stdClass();
            $data->courseid = $courseid;
            $data->name = $groupcode;
            $data->idnumber = $idnumber;
            $groupid = groups_create_group($data);
        }
        if ($groupid) {
            groups_add_member($groupid, $user->id, 'enrol_ubxsshib', $this->instance->id);
        }
    }

    protected function get_coursegroup_identifier($groupcode) {
        return 'ub:' . $this->instance->id . ':' . $this->customchar2 . ':' . $groupcode;
    }
}
