<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * UBxS shibboleth enrol plugin upgrade
 *
 * @package    enrol_ubxsshib
 * @copyright  2011 Christophe Michenaud
 * @author     Christophe Michenaud
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/**
 * Performs upgrade of the database structure and data
 *
 * @param int $oldversion the version we are upgrading from
 * @return bool true
 */
function xmldb_enrol_ubxsshib_upgrade($oldversion) {
    global $CFG, $DB;

    $dbman = $DB->get_manager();

    if ($oldversion < 2012040002) {
        $rs = $DB->get_recordset('enrol', ['enrol' => 'ubxsshib']);
        foreach ($rs as $record) {
            $DB->set_field('enrol', 'customchar2', $record->customchar1, ['id' => $record->id]);
            $DB->set_field('enrol', 'customchar1', '0331765P', ['id' => $record->id]);
        }
        $rs->close();

        upgrade_plugin_savepoint(true, 2012040002, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2012090500) {
        $rs = $DB->get_recordset('enrol', ['enrol' => 'ubxsshib']);
        foreach ($rs as $record) {
            $DB->set_field('enrol', 'customint1', 0, ['id' => $record->id]);
        }
        $rs->close();

        upgrade_plugin_savepoint(true, 2012090500, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2013062000) {
        // Define table ubxsshib_login_log to be created.
        $table = new xmldb_table('ubxsshib_login_log');

        // Adding fields to table checklist_comment.
        $table->add_field('id', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, XMLDB_SEQUENCE, null);
        $table->add_field('username', XMLDB_TYPE_CHAR, '100', null, null, null, null);
        $table->add_field('logintime', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, null, null, '0');
        $table->add_field('etuetape', XMLDB_TYPE_TEXT, 'medium', null, null, null, null);
        $table->add_field('etuelempedago', XMLDB_TYPE_TEXT, 'medium', null, null, null, null);

        // Adding keys to table ubxsshib_login_log.
        $table->add_key('primary', XMLDB_KEY_PRIMARY, ['id']);

        // Conditionally launch create table for ubxsshib_login_log.
        if (!$dbman->table_exists($table)) {
            $dbman->create_table($table);
        }

        upgrade_plugin_savepoint(true, 2013062000, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014040400) {
        upgrade_plugin_savepoint(true, 2014040400, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014040401) {
        $rs = $DB->get_recordset('enrol', ['enrol' => 'ubxsshib']);
        foreach ($rs as $record) {
            $DB->set_field('enrol', 'customchar1', 'ETP', ['id' => $record->id]);
        }
        $rs->close();

        upgrade_plugin_savepoint(true, 2014040401, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014040402) {
        upgrade_plugin_savepoint(true, 2014040402, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014092600) {
        upgrade_plugin_savepoint(true, 2014092600, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014093000) {
        upgrade_plugin_savepoint(true, 2014093000, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014093001) {
        upgrade_plugin_savepoint(true, 2014093001, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2014093002) {
        upgrade_plugin_savepoint(true, 2014093002, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2018011900) {
        upgrade_plugin_savepoint(true, 2018011900, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2018012500) {
        upgrade_plugin_savepoint(true, 2018012500, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2018020800) {
        upgrade_plugin_savepoint(true, 2018020800, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2018022300) {
        upgrade_plugin_savepoint(true, 2018022300, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2018022800) {
        upgrade_plugin_savepoint(true, 2018022800, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2019041900) {
        upgrade_plugin_savepoint(true, 2019041900, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2019041901) {
        upgrade_plugin_savepoint(true, 2019041901, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2020042500) {
        upgrade_plugin_savepoint(true, 2020042500, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2020042702) {
        // Define table ubxsshib_login_log to be created.
        $table = new xmldb_table('ubxsshib_login_log');
        $field = new xmldb_field('etuepreuve', XMLDB_TYPE_TEXT, 'medium', null, null, null, null, 'etuelempedago');

        if (!$dbman->field_exists($table, $field)) {
            $dbman->add_field($table, $field);
        }

        upgrade_plugin_savepoint(true, 2020042702, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2020083100) {
        upgrade_plugin_savepoint(true, 2020083100, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2020091200) {
        upgrade_plugin_savepoint(true, 2020091200, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2020111500) {
        upgrade_plugin_savepoint(true, 2020111500, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2021071800) {
        upgrade_plugin_savepoint(true, 2021071800, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2021072200) {
        upgrade_plugin_savepoint(true, 2021072200, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2022032401) {
        upgrade_plugin_savepoint(true, 2022032401, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2022032801) {
        upgrade_plugin_savepoint(true, 2022032801, 'enrol', 'ubxsshib');
    }

    if ($oldversion < 2025040100) {
        upgrade_plugin_savepoint(true, 2025040100, 'enrol', 'ubxsshib');
    }
    return true;
}
