<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Adds new instance of enrol_ubxsshib to specified course
 * or edits current instance.
 *
 * @package    enrol_ubxsshib
 * @copyright  2011 Christophe Michenaud
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require('../../config.php');

use enrol_ubxsshib\ubxsshib_enrol_method;
use enrol_ubxsshib\form\edit_form;

$courseid   = required_param('courseid', PARAM_INT);
$instanceid = optional_param('id', 0, PARAM_INT);

$course = $DB->get_record('course', ['id' => $courseid], '*', MUST_EXIST);
$context = context_course::instance($course->id);

require_login($course);
require_capability('enrol/ubxsshib:config', $context);

$PAGE->set_url('/enrol/ubxsshib/edit.php', ['courseid' => $course->id, 'id' => $instanceid]);
$PAGE->set_pagelayout('admin');

$return = new moodle_url('/enrol/instances.php', ['id' => $course->id]);

if (!enrol_is_enabled('ubxsshib')) {
    redirect($return);
}

$plugin = enrol_get_plugin('ubxsshib');

if ($instanceid) {
    $instance = $DB->get_record(
        'enrol',
        ['courseid' => $course->id, 'enrol' => 'ubxsshib', 'id' => $instanceid],
        '*',
        MUST_EXIST);
} else {
    require_capability('moodle/course:enrolconfig', $context);
    // No instance yet, we have to add new instance.
    navigation_node::override_active_url(new moodle_url('/enrol/instances.php', ['id' => $course->id]));
    $instance = new stdClass();
    $instance->id = null;
    $instance->courseid = $course->id;
}

$mform = new edit_form(null, [$instance, $plugin, $context]);

if ($mform->is_cancelled()) {
    redirect($return);

} else if ($data = $mform->get_data()) {
    if ($instance->id) {
        $instance->name = $data->name;
        $instance->status = $data->status;
        $instance->roleid = $data->roleid;
        $instance->customchar1 = strtoupper(trim($data->customchar1));
        $instance->customchar2 = strtoupper(trim($data->customchar2));
        $instance->customint1 = ($data->customint1 != ubxsshib_enrol_method::NO_GROUP) ? $data->customint1 : null;
        $instance->enrolstartdate = $data->enrolstartdate;
        $instance->enrolenddate = $data->enrolenddate;
        $instance->timemodified = time();
        $DB->update_record('enrol', $instance);
    } else {
        $fields = [
            'status' => $data->status,
            'roleid' => $data->roleid,
            'name' => $data->name,
            'customchar1' => strtoupper($data->customchar1),
            'customchar2' => strtoupper($data->customchar2),
            'customint1' => ($data->customint1 == ubxsshib_enrol_method::NO_GROUP) ? null : $data->customint1,
            'enrolstartdate' => $data->enrolstartdate,
            'enrolenddate' => $data->enrolenddate,
        ];
        $plugin->add_instance($course, $fields);
    }
    redirect($return);
}

$PAGE->set_heading($course->fullname);
$PAGE->set_title(get_string('pluginname', 'enrol_ubxsshib'));

echo $OUTPUT->header();
echo $OUTPUT->heading(get_string('pluginname', 'enrol_ubxsshib'));
echo '<blockquote>' .
    get_string('methoddescription', 'enrol_ubxsshib').
    '</blockquote>';

$mform->display();
echo $OUTPUT->footer();
