<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Displays login form for both manual and shibboleth auth methods
 *
 * @package    enrol_ubxsshib
 * @copyright  2011 Christophe Michenaud
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

define('NO_MOODLE_COOKIES', true);
require('../../config.php');
require_once("$CFG->libdir/formslib.php");

redirect_if_major_upgrade_required();

$PAGE->https_required();

$PAGE->set_context(context_system::instance());
$PAGE->set_url('/enrol/ubxsshib/login.php');
$PAGE->set_title('Connexion');
$PAGE->set_heading('Connexion');
$PAGE->set_pagelayout('login');

$urlshibconnection = str_replace("http://", "https://", "$CFG->wwwroot//auth/shibboleth/index.php");
$urlcasconnection = "$CFG->wwwroot/login/index.php?authCAS=CAS";
$urlloginform = "$CFG->httpwwwroot/login/index.php";

echo $OUTPUT->header();
?>
    <div style="overflow:hidden; position:relative;">
        <div style="width:40%; padding:15px; float:left;">
            <h2>Utilisateurs Université de Bordeaux</h2>
            <p style="padding-left:20px;">
                Veuillez vous <a href="<?php echo $urlcasconnection;?>">connecter avec votre Campus-Pass</a>.<br />
                <br />
                En fin de session, n'oubliez pas de vous <b>déconnecter</b> et de <b>fermer votre navigateur</b>.
            </p>
        </div>
        <div style="width:50%; border-left:solid 1px black;padding:15px; float:right;">
            <h2>Autres utilisateurs</h2>
            <p>
                Cet accès est réservé à des comptes spéciaux.<br />
                Aucune demande de compte utilisateur pour cet accès ne peut être faite.
            </p>
            <p style="padding-left:20px;">
            <div class="subcontent loginsub">
                <div class="desc">
                    <?php
                    echo get_string("cookiesenabled");
                    echo $OUTPUT->help_icon('cookiesenabled');
                    ?>
                </div>
                <?php
                if (!empty($errormsg)) {
                    echo html_writer::start_tag('div', ['class' => 'loginerrors']);
                    echo html_writer::link('#', $errormsg, ['id' => 'loginerrormessage', 'class' => 'accesshide']);
                    echo $OUTPUT->error_text($errormsg);
                    echo html_writer::end_tag('div');
                }
                ?>
                <br />
                <form action="<?php echo $urlloginform; ?>" method="post" id="login" >
                    <div class="loginform">
                        <div class="form-label"><label for="username"><?php print_string("username") ?></label></div>
                        <div class="form-input">
                            <input type="text" name="username" id="username" size="15" />
                        </div>
                        <div class="clearer"><!-- --></div>
                        <div class="form-label"><label for="password"><?php print_string("password") ?></label></div>
                        <div class="form-input">
                            <input type="password" name="password" id="password" size="15" value="" /><br />
                            <input type="submit" id="loginbtn" value="<?php print_string("login") ?>" />
                        </div>
                        <div class="clearer"><!-- --></div>
                    </div>
                    <div class="clearer"><!-- --></div>
                    <br />
                    <div class="forgetpass"><a href="/login/forgot_password.php"><?php print_string("forgotten") ?></a></div>
                </form>
            </div>
            </p>
        </div>
    </div>
<?php
echo $OUTPUT->footer();
