<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Search page for UBxS shibboleth enrol plugin.
 *
 * @package    enrol_ubxsshib
 * @copyright  2014 Christophe Michenaud
 * @author     Christophe Michenaud
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../config.php');
require_once("$CFG->dirroot/enrol/ubxsshib/locallib.php");

use context_system;
use context_course;
use enrol_ubxsshib\form\search_form;
use enrol_ubxsshib\ldap_provider;

global $PAGE;

$courseid   = optional_param('course', 0, PARAM_INT);
$codetype   = required_param('codetype', PARAM_TEXT);
$course = null;

if ($courseid) {
    $course = $DB->get_record('course', ['id' => $courseid], '*', MUST_EXIST);
    $context = context_course::instance($course->id);
    require_login($course);
    require_capability('enrol/ubxsshib:config', $context);
} else {
    $context = context_system::instance();
    require_login();
}

$PAGE->set_url($CFG->wwwroot . '/enrol/ubxsshib/search.php');
$PAGE->set_pagelayout('popup');
$PAGE->set_context($context);
$PAGE->set_title(get_string('pluginname', 'enrol_ubxsshib'));

$mform = new search_form(null, [$course, $codetype]);

echo $OUTPUT->header();

if ($mform->is_cancelled()) {
    $PAGE->requires->js_call_amd('enrol_ubxsshib/search', 'closesWindow');
}

$mform->display();

if ($data = $mform->get_data()) {
    $repository = new ldap_provider();
    $results = $repository->search_groups($data->searchtext, $codetype);
    $renderer = $PAGE->get_renderer('enrol_ubxsshib');
    $renderer->search_results($results);
    $PAGE->requires->js_call_amd('enrol_ubxsshib/search', 'initSearchForm');
}

echo $OUTPUT->footer();
