<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Apogee enrolments plugin settings and presets.
 *
 * @package    enrol_ubxsshib
 * @copyright  2011 Christophe Michenaud
 * @author     Christophe Michenaud - based on code by Petr Skoda and others
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot . '/enrol/ldap/settingslib.php');
require_once($CFG->dirroot . '/course/lib.php');

if ($ADMIN->fulltree) {
    $yesno = [get_string('no'), get_string('yes')];

    // Settings.
    $settings->add(new admin_setting_heading('enrol_ubxsshib_settings', '', get_string('pluginname_desc', 'enrol_ubxsshib')));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/systemcoursecreator_filter', get_string('systemcoursecreator_filter', 'enrol_ubxsshib'), get_string('systemcoursecreator_filter_desc', 'enrol_ubxsshib'), '(edupersonaffiliation=teacher)'));
    $allroles = get_all_roles(null);
    $sysrolesids = [];
    $sysroles = get_roles_for_contextlevels(CONTEXT_SYSTEM);
    foreach ($sysroles as $key => $value) {
        array_push($sysrolesids, intval($value));
    }
    $roles = [];
    foreach ($allroles as $role) {
        if (in_array($role->id, array_values($sysrolesids))) {
            $roles[$role->id] = $role;
        }
    }
    $selectableroles = role_fix_names($roles, null, ROLENAME_ORIGINALANDSHORT, true);
    $settings->add(new admin_setting_configmultiselect('enrol_ubxsshib/systemroleids', get_string('systemroles', 'enrol_ubxsshib'), get_string('systemroles_desc', 'enrol_ubxsshib'), [], $selectableroles));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/sandboxcoursecreator_filter', get_string('sandboxcoursecreator_filter', 'enrol_ubxsshib'), get_string('sandboxcoursecreator_filter_desc', 'enrol_ubxsshib'), '(|(edupersonaffiliation=employee)(edupersonaffiliation=staff)(edupersonaffiliation=teacher)(edupersonaffiliation=researcher)(edupersonaffiliation=faculty))'));
    $categorieslist = core_course_category::make_categories_list();
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/sandboxid',
        get_string('sandboxid', 'enrol_ubxsshib'), get_string('sandboxid_help', 'enrol_ubxsshib'), 0, $categorieslist));
    $options = $yesno;
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/inhibit_all', get_string('inhibit_all_methods', 'enrol_ubxsshib'), get_string('inhibit_all_methods_desc', 'enrol_ubxsshib'), 0, $options));

    $settings->add(new admin_setting_heading('enrol_ubxsshib_testing_settings', get_string('testing_heading', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configcheckbox('enrol_ubxsshib/logattributes',
        get_string('logattributes', 'enrol_ubxsshib'), get_string('logattributes_desc', 'enrol_ubxsshib'), 0));
    $options = $yesno;
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/usertooverride',
        get_string('usertooverride', 'enrol_ubxsshib'), get_string('usertooverride_desc', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/etp_forcedattributes',
        get_string('etp_forcedattributes', 'enrol_ubxsshib'), get_string('etp_forcedattributess_desc', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/elp_forcedattributes',
        get_string('elp_forcedattributes', 'enrol_ubxsshib'), get_string('elp_forcedattributes_desc', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/exam_forcedattributes',
        get_string('exam_forcedattributes', 'enrol_ubxsshib'), get_string('exam_forcedattributes_desc', 'enrol_ubxsshib'), ''));

    $options = $yesno;
    $settings->add(new admin_setting_heading('enrol_ubxsshib_server_settings', get_string('server_settings', 'enrol_ldap'), ''));
    $settings->add(new admin_setting_configtext_trim_lower('enrol_ubxsshib/host_url', get_string('host_url_key', 'enrol_ldap'), get_string('host_url', 'enrol_ldap'), ''));
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/start_tls', get_string('start_tls_key', 'auth_ldap'), get_string('start_tls', 'auth_ldap'), 0, $options));

    $options = [3 => '3', 2 => '2'];
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/ldap_version', get_string('version_key', 'enrol_ldap'), get_string('version', 'enrol_ldap'), 3, $options));

    $settings->add(new admin_setting_heading('enrol_ldap_bind_settings', get_string('bind_settings', 'enrol_ldap'), ''));
    $settings->add(new admin_setting_configtext_trim_lower('enrol_ubxsshib/bind_dn', get_string('bind_dn_key', 'enrol_ldap'), get_string('bind_dn', 'enrol_ldap'), ''));
    $settings->add(new admin_setting_configpasswordunmask('enrol_ubxsshib/bind_pw', get_string('bind_pw_key', 'enrol_ldap'), get_string('bind_pw', 'enrol_ldap'), ''));

    $options = $yesno;
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/user_search_sub', get_string('user_search_sub_key', 'enrol_ldap'), get_string('user_search_sub', 'enrol_ldap'), 0, $options));
    $options = [];
    $options[LDAP_DEREF_NEVER] = get_string('no');
    $options[LDAP_DEREF_ALWAYS] = get_string('yes');
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/opt_deref', get_string('opt_deref_key', 'enrol_ldap'), get_string('opt_deref', 'enrol_ldap'), 0, $options));

    $settings->add(new admin_setting_heading('enrol_ldap_properties_settings', 'Propriétés', ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/user_dn_base', get_string('user_dn_base', 'enrol_ubxsshib'), get_string('user_dn_base_desc', 'enrol_ubxsshib'), 'ou=people,dc=u-bordeaux,dc=fr'));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/username_property', get_string('username_property', 'enrol_ubxsshib'), get_string('username_property_desc', 'enrol_ubxsshib'), 'uid'));
    $options = ['cas' => 'CAS', 'shibboleth' => 'Shibboleth'];
    $settings->add(new admin_setting_configselect('enrol_ubxsshib/auth_method', get_string('auth_method', 'enrol_ubxsshib'), get_string('auth_method_desc', 'enrol_ubxsshib'), 'shibboleth', $options));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/memberof_property', get_string('memberof_property', 'enrol_ubxsshib'), get_string('memberof_property_desc', 'enrol_ubxsshib'), 'memberof'));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_dn_base', get_string('group_dn_base', 'enrol_ubxsshib'), get_string('group_dn_base_desc', 'enrol_ubxsshib'), 'ou=groups,dc=u-bordeaux,dc=fr'));

    $settings->add(new admin_setting_heading('enrol_ldap_etapes_settings', get_string('group_etape_setting_heading', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_etape_name_property', get_string('group_etape_name_property', 'enrol_ubxsshib'), get_string('group_etape_name_property_desc', 'enrol_ubxsshib'), 'cn'));
    $settings->add(new admin_setting_configtextarea('enrol_ubxsshib/group_etape_pattern', get_string('group_etape_pattern', 'enrol_ubxsshib'), get_string('group_etape_pattern_desc', 'enrol_ubxsshib'), 'ubx:etud:etapes:*:%CODE%', PARAM_RAW, '60', '3'));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_etape_search_property', get_string('group_etape_search_property', 'enrol_ubxsshib'), get_string('group_etape_search_property_desc', 'enrol_ubxsshib'), 'description'));

    $settings->add(new admin_setting_heading('enrol_ldap_elp_settings', get_string('group_elp_setting_heading', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_elp_name_property', get_string('group_elp_name_property', 'enrol_ubxsshib'), get_string('group_elp_name_property_desc', 'enrol_ubxsshib'), 'cn'));
    $settings->add(new admin_setting_configtextarea('enrol_ubxsshib/group_elp_pattern', get_string('group_elp_pattern', 'enrol_ubxsshib'), get_string('group_elp_pattern_desc', 'enrol_ubxsshib'), 'ubx:etud:ue:%CODE%', PARAM_RAW, '60', '3'));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_elp_search_property', get_string('group_elp_search_property', 'enrol_ubxsshib'), get_string('group_elp_search_property_desc', 'enrol_ubxsshib'), 'description'));

    $settings->add(new admin_setting_heading('enrol_ldap_exam_settings', get_string('group_exam_setting_heading', 'enrol_ubxsshib'), ''));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_exam_name_property', get_string('group_exam_name_property', 'enrol_ubxsshib'), get_string('group_exam_name_property_desc', 'enrol_ubxsshib'), 'cn'));
    $settings->add(new admin_setting_configtextarea('enrol_ubxsshib/group_exam_pattern', get_string('group_exam_pattern', 'enrol_ubxsshib'), get_string('group_exam_pattern_desc', 'enrol_ubxsshib'), 'ubx:etud:epreuv:%CODE%', PARAM_RAW, '60', '3'));
    $settings->add(new admin_setting_configtext('enrol_ubxsshib/group_exam_search_property', get_string('group_exam_search_property', 'enrol_ubxsshib'), get_string('group_exam_search_property_desc', 'enrol_ubxsshib'), 'description'));
}
